@@ -8,7 +8,7 @@ from fabric.colors import *
 from fabric.contrib.console import confirm
 from ground_soil.fabric import eval_kwargs, virtual_env
 from ground_soil.filesystem import temporary_directory, render_file, sed
-from beanstalk import IDENTIFIER, BEANSTALK_ROOT_PATH
+from beanstalk import IDENTIFIER, BEANSTALK_ROOT_PATH, BEANSTALK_GLOBAL_BASE_PATH
 from beanstalk.decorators import beanstalk_role
 from beanstalk.paths.server import (project_base_path, project_source_path, project_logs_path, project_venv_path,
                                     project_uwsgi_path, apache_conf_path, app_ports_path)
@@ -128,14 +128,15 @@ def setup(settings_path=None, **settings_patches):
     local('chmod o+rx %s' % beanstalk_stack_base)
 
     # Global ini
-    local('mkdir -p /etc/beanstalk')
-    if not os.path.exists('/etc/beanstalk/uwsgi.ini'):
+    local('mkdir -p {0}'.format(BEANSTALK_GLOBAL_BASE_PATH))
+    global_uwsgi_ini_path = os.path.join(BEANSTALK_GLOBAL_BASE_PATH, 'uwsgi.ini')
+    if not os.path.exists(global_uwsgi_ini_path):
         print section_title('Create global settings')
         global_uwsgi_ini_template_path = os.path.join(BEANSTALK_ROOT_PATH, 'static/global_uwsgi.ini')
         with hide('everything'):
             uid = local('id -u apache', capture=True)
         global_uwsgi_ini_content = render_file(global_uwsgi_ini_template_path, beanstalk_settings, BEANSTALK_UID=uid)
-        with open('/etc/beanstalk/uwsgi.ini', 'w') as f:
+        with open(global_uwsgi_ini_path, 'w') as f:
             f.write(global_uwsgi_ini_content)
 
     # Apache command
